#!/usr/bin/tclsh

# The problem is that there are some elements that could not
# be translated by TTH. So we will convert them in this
# postprocess.

# Usage: convert_html_post.tcl file.html 10 2010 [1]
# The optional 1 at the end tells if images should be kept
# or removed.

if { $argc == 3 || $argc == 4 } {

    # open file    
    set file [open [lindex $argv 0] r]

    # month
    set MONAT [lindex $argv 1]

    # year
    set JAHR [lindex $argv 2]

    # flag if images should be ignored
    set ignoreImages 0
    if { $argc == 4 } {
        set ignoreImages 1
    }

    # flag if this is a listing
    set listingStarted 0
    set listingStartedOld 0

    # flag if this is a command box
    set commandStarted 0
    set commandStartedOld 0

    # flag if the line is part of the content
    # this is necessary for the epub
    set contentStarted 0

    # flag that paragraph-div should be ignored
    set ignoreParagraphBreak 0

    #  flag if we after the impressum
    set afterImpressum 0

    # iterate over all lines
    while { [gets $file line] >= 0 } {

        if { !$listingStarted && !$commandStarted &&
             !$listingStartedOld && !$commandStartedOld } {
            # only replace if no Listing has been started

            # set title
            if { [regsub -all {<title>.*</title>} $line "<title>freiesMagazin $MONAT/$JAHR</title>\n" line] } {

                # add meta-tags
                append line {<meta http-equiv="content-type" content="text/html; charset=utf-8" />}
                append line "\n"
                append line {<meta http-equiv="content-language" content="de" />}
                append line "\n"
                append line {<meta name="publisher" content="Dominik Wagenführ" />}
                append line "\n"
                append line {<meta name="author" content="freiesMagazin-Autoren" />}
                append line "\n"
                append line {<meta name="description" content="Magazin rund um Linux und Open Source" />}
                append line "\n"
                append line {<meta name="keywords" content="freiesMagazin, freies, Magazin, Linux, Open Source" />}
                append line "\n"
                append line {<meta name="copyright" content="CC-BY-SA 4.0 Unported" />}
                append line "\n"
                append line {<meta name="issn" content="1867-7991" />}
                append line "\n"
                append line "<meta name=\"title\" content=\"freiesMagazin $MONAT/$JAHR\" />"
                append line "\n"
                append line {<meta name="language" content="German" />}
                append line "\n"
                append line "\n"

                append line {<link type="text/css" rel="stylesheet" href="fm_mobil_2013_08.css" />}
                append line "\n"
            }

            # set correct System Identifier vor XHTML
            regsub {DTD/xhtml1-transitional.dtd} $line {http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd} line

            if { $ignoreImages == 0 } {
                # replace images
                regsub -all {<a href="([^"]*)">Figure</a>} $line {<img src="\1" />} line
                
                #" Kommentar wegen Editor (Anführungszeichen)

                # set image link
                regsub -all {src="Bilder/([^"]*)"} $line "src=\"$JAHR-$MONAT-bilder/\\1\" alt=\"\\1\" style=\"max-width:100%\"" line
            } else {
                # remove images
                regsub -all {<a href="([^"]*)">Figure</a>} $line {} line
            }
            
            # set korrekt Link to images because tth could not to this
            regsub -all {\\Jahr} $line "$JAHR" line
            regsub -all {\\Monat} $line "$MONAT" line

            # set correct body font
            if { [regsub {<body>} $line {<body style="font-family: sans-serif;">} line] } {
                # we are at the start of the file and need to add the
                # link to the other version 
                if { $ignoreImages == 0 } {
                    append line "<font size=\"5\"><a href=\"freiesMagazin-$JAHR-$MONAT.html\">Zur Version ohne Bilder</a></font><hr />"
                } else {
                    append line "<font size=\"5\"><a href=\"freiesMagazin-$JAHR-$MONAT-bilder.html\">Zur Version mit Bildern</a></font><hr />"
                }
            }

            # remove invalid compact-tag for <dl>
            regsub {<dl compact="compact">} $line {<dl>} line

            # set listing link
            regsub -all {href="Listings/([^"]*)} $line "href=\"$JAHR-$MONAT-listings/\\1" line

            # replace HTML-Backslash
            regsub -all {\[HTML-BACKSLASH\]} $line {\\} line

            # replace HTML-Tilde
            regsub -all {\[HTML-TILDE\]} $line {~} line

            # replace HTML-Bar
            regsub -all {\[HTML-STRICH\]} $line {|} line

            # replace freiesMagazin-Mail
            regsub -all {\[FMMAIL\]} $line {<img src="http://www.freiesmagazin.de/system/files/redaktionmail.png" alt="redaktion ETT freiesmagazin PUNKT de" height="17" width="168" align="top" />} line

            # set correct anchors
            # Das 'fm_' is notwendig, weil ids mit einem Buchstaben anfangen muessen,
            # bei uns fangen sie aber mit 12_12_titel an.
            regsub -all {<a name="(.*?)">} $line {<a id="fm_\1" name="fm_\1">} line

            # Wir muessen daraufhin auch alle internern Verweise auf fm_12_12_... aendern.
            regsub -all {<a href="#(.*?)">} $line {<a href="#fm_\1">} line

            # set horizontal line under link to index
            if { [regexp {<a href="#fm_index">Zum Index</a>} $line] } {
                if { $afterImpressum } {
                    # Nach dem Impressum gibt es keine Linie mehr
                    regsub -all {<a href="#fm_index">Zum Index</a>} $line {} line
                } else {
                    regsub -all {<a href="#fm_index">Zum Index</a>} $line {<a href="#fm_index">Zum Index</a><br /><hr />} line
                }
            }
            regsub -all {<br /><br /><hr />} $line {} line
            regsub -all {<hr />} $line {<hr class="sigilChapterBreak" />} line

            # replace all spans by divs
            regsub -all {<span>} $line {<div>} line
            regsub -all {<span } $line {<div } line
            regsub -all {</span>} $line {</div>} line

            # replace <tt> with css-style
            regsub -all {<tt>} $line {<tt class="big">} line

            # Aufzaehlungen korrigieren
            regsub -all {<ol type=.*>} $line {<ol>} line

            # replace different chars
            if { ![regexp "DOCTYPE" $line] && ![regexp "<font size=\"-" $line]} {
                # do not replace in DOCTYPE!
                regsub -all {"-} $line {} line
                #" Kommentar wegen Editor (Anführungszeichen)
            }
            regsub -all {""} $line {} line
            regsub -all {,,} $line {„} line
            regsub -all {''} $line {“} line
            regsub -all {\\#} $line {#} line
            regsub -all {\\%} $line {%} line

            # Tabellen korrigieren
            regsub -all {<tr><td align="left"> *</td></tr>} $line {} line
            regsub -all {<td width="[0-9]*">} $line {<td>} line
            regsub -all {<tr><td> *</td></tr>} $line {} line
            regsub -all {<font size="\+0">(.*)</font>} $line {\1} line
            regsub -all {<table border="1">} $line {<table border="1" cellspacing="0" cellpadding="3">} line
            regsub -all {<font size="\+0">} $line {} line
            regsub -all {</td></tr></font></font></font></font></font></font></font></table>} $line {</td></tr></table>} line

            # Ampersand & in Links ersetzen, damit W3C-valide.
            if { [regexp {<a href="[^"]*">} $line link] } {
                # Das & muss in TCL maskiert werden.
                regsub -all {&} $link {\\\&amp;} link
                regsub {<a href="[^"]*">} $line $link line
            }

            if { [regexp {<a name=".*_impressum">Impressum} $line] } {
                # Wir nehmen an, dass das Impressum immer die letzte
                # Seite ist
                set afterImpressum 1
            }


        } ;# Listing-Ende

        if { $listingStarted || $commandStarted  } {

            set cssclass ""
            if { $listingStarted } {
                set cssclass "listing"
            } else {
                set cssclass "command"
            }

            set newline 1
            if { [regsub {<pre>} $line "<div class=\"$cssclass\">" line] } {
                set newline 0
            }
            if { [regsub {</pre>} $line {</div>} line] } {
                set newline 0
            }
            # In den Listings, die mit Verbatim umgesetzt wurden,
            # muessen wir am Ende ein Break anfuegen, sonst steht alles
            # in einer Zeile.
            if { $newline } {
                append line {<br />}
            }
            
            if { [regexp {^(&nbsp;)*} $line spaces] } {
                regsub -all {&nbsp;} $line " " line
                set line $spaces[string trim $line " "]
            }
        }

        if { [regexp {\[LISTINGUMG\]} $line] } {
            # a new listing has been started
            set listingStarted 1
            regsub {\[LISTINGUMG\]} $line {} line
        }

        if { [regexp {\[/LISTINGUMG\]} $line] } {
            # listing has ended
            set listingStarted 0
            regsub {\[/LISTINGUMG\]} $line {} line
        }

        if { [regexp {\[BEFEHLUMG\]} $line] } {
            # a new command has been started
            set commandStarted 1
            regsub {\[BEFEHLUMG\]} $line {} line
        }

        if { [regexp {\[/BEFEHLUMG\]} $line] } {
            # command has ended
            set commandStarted 0
            regsub {\[/BEFEHLUMG\]} $line {} line
        }

        if { [regexp {\[LISTINGUMG\]} $line] } {
            # a new listing has been started
            set listingStartedOld 1
            regsub {\[LISTINGUMG_ALT\]} $line {<div class="listing">} line
        }

        if { [regexp {\[/LISTINGUMG_ALT\]} $line] } {
            # listing has ended
            set listingStartedOld 0
            regsub {\[/LISTINGUMG_ALT\]} $line {</div>} line
        }

        if { [regexp {\[BEFEHLUMG_ALT\]} $line] } {
            # a new command has been started
            set commandStartedOld 1
            regsub {\[BEFEHLUMG_ALT\]} $line {<div class="command">} line
        }

        if { [regexp {\[/BEFEHLUMG_ALT\]} $line] } {
            # command has ended
            set commandStartedOld 0
            regsub {\[/BEFEHLUMG_ALT\]} $line {</div>} line
        }

        if { [regexp {\[INFOBOX\]} $line] } {
            # a new infobox has been started
            regsub {\[INFOBOX\]} $line {<div class="infobox">} line
        }

        if { [regexp {\[/INFOBOX\]} $line] } {
            # info box has ended
            regsub {\[/INFOBOX\]} $line {</div>} line
        }

        if { [regexp {^<div class="p"><!----></div>$} $line] ||
             [regexp {^<br />$} $line] } {
            # Wenn wir einen "Absatz" findet, entscheiden wir abhaengig
            # von der vorhergehenden Zeile, ob wir den Absatz wirklich
            # wollen. In vielen Faellen ist er naemlich unnoetig.
            if { $ignoreParagraphBreak } {
                set line ""
            }
        }

        # Inhaltsverzeichnis taggen
        if { [regexp {<a id="fm_index" name="fm_index">Inhalt</a>} $line] } {
            set contentStarted 1
        }

        if { $contentStarted && ![regexp {^ *$} $line] } {
            append line "<!-- CONTENT -->"
        }

        if { [regexp {<a href="#fm_index">Zum Index</a>} $line] } {
            set contentStarted 0
        }

        puts $line

        # Absatzkontrolle am Ende
        if { [regexp {<body style} $line] ||
             [regexp {<div class="p"><!----></div>} $line] ||
             [regexp {</h[0-9]>(<!-- CONTENT -->)?$} $line] ||
             [regexp {<hr />(<!-- CONTENT -->)?$} $line] ||
             [regexp {<br /><br />} $line] } {
            set ignoreParagraphBreak 1
        } elseif { ![regexp {^ *$} $line] } {
            # leere Zeilen veraendern den alten Zustand nicht
            set ignoreParagraphBreak 0
        }
    }
    
} else {
    puts "Error: Only one argument allowed!"
}
